import router from "../router/index";
import dayjs from "dayjs"; // 时间格式化组件
import { showToast } from "vant";

const { VITE_BASE_URL } =
import.meta.env;
// 在新的页面打开路由
export const routerOpenInNewWindow = routerPath => {
    let routeData = router.resolve(routerPath);
    window.open(routeData.href, "_blank");
};

/**
 *
 * @param {*} path 图片路径
 * @returns
 */
export const formatImg = path => {
    return path ? `${VITE_BASE_URL}/common/getImg?path=${path}` : "";
    // return path ? `http://shuyuan.test.hhrchina.com/filex/img/${path}` : "";
};

/**
 *
 * @param {*} path 图片路径
 * @returns
 */
export const formatVideo = path => {
    return path ? `${VITE_BASE_URL}/common/getVideo?path=${path}` : "";
};

/**
 *
 * @param {*} time 时间
 * @param {*} fmtString 转换的格式
 * @returns
 */
export const formatDate = (time, fmtString) => {
    time = new Date(time);
    // 使用dayjs这个日期格式化类库实现日期的格式化功能
    if (time == "" || !time) {
        return "——";
    } else {
        return dayjs(time).format(fmtString);
    }
};

/**
 *
 * @param {*} ary 数组
 * @param {*} key 根据key值排序
 * @returns
 */
export const sortByKey = (ary, key) => {
    return ary.sort(function(a, b) {
        let x = a[key];
        let y = b[key];
        return x < y ? -1 : x > y ? 1 : 0;
    });
};

/**
 *
 * @param {*} val string
 * @returns
 */
export const toast = (val, type) => {
    const isMobile = /Android|webOS|iPhone|iPod|BlackBerry|iPad/i.test(navigator.userAgent);
    if (isMobile) {
        showToast({
            message: val,
            className: "tip",
        });
    } else {
        ElMessage({
            message: val,
            type,
        });
    }
};

export const debounce = (func, delay) => {
    let timer = null;
    return function(...args) {
        clearTimeout(timer);
        timer = setTimeout(() => {
            func.apply(this, args);
        }, delay);
    };
};

export const throttle = (func, wait) => {
    let timer;
    return () => {
        if (timer) {
            return;
        }
        timer = setTimeout(() => {
            func();
            timer = null;
        }, wait);
    };
};