import {
    getAreaData,
    getAreaIndustrialAllocationList,
    updateAreaInfoManagementPageView,
    getRegistrationPackageByFirst,
} from "@/apis/index";
import { toast } from "@/utils/common.js";

export function getHomeData() {
    // 获取数据
    const getData = async() => {
        let data;
        try {
            let res = await getAreaData();
            if (res.data.status == 0) {
                data = res.data.data;
            } else {
                toast(res.data.msg, "error");
            }
        } catch (error) {
            toast("获取数据失败，请刷新重试！", "error");
        }
        return data;
    };

    // 获取主导产业
    const getAreaIndustrialAllocation = async() => {
        let data;
        try {
            let res = await getAreaIndustrialAllocationList();
            if (res.data.status == 0) {
                data = res.data.data;
            } else {
                toast(res.data.msg, "error");
            }
        } catch (error) {
            toast("获取主导产业失败，请刷新重试！", "error");
        }
        return data;
    };

    // 获取最近那一个编辑或者上架的招商载体
    const getRegistrationPackage = async() => {
        let data;
        let res = await getRegistrationPackageByFirst();
        if (res.data.status == 0) {
            data = res.data.data;
        }
        return data;
    };

    const setDetailPolicy = homeData => {
        const detailPolicy = ref([]);
        if (homeData) {
            const {
                policyTitle,
                policyText,
                policySubtitleI,
                policyContentI,
                policySubtitleII,
                policyContentII,
            } = homeData;
            detailPolicy.value = [{
                    title: policyTitle,
                    content: policyText,
                },
                {
                    title: policySubtitleI,
                    content: policyContentI,
                },
                {
                    title: policySubtitleII,
                    content: policyContentII,
                },
            ];
        }
        return detailPolicy;
    };

    const setPolicy = homeData => {
        const policy = ref([]);
        if (homeData) {
            const { fiscalTaxationPolicy, talentRelatedPolicy, industryRelatedPolicy } = homeData;
            policy.value = [{
                    title: "财税政策",
                    content: fiscalTaxationPolicy,
                    color: "#333",
                    bgColor: "rgb(255, 242, 197)",
                },
                {
                    title: "人才相关政策",
                    content: talentRelatedPolicy,
                    color: "#333",
                    bgColor: "rgba(172, 217, 255, 1)",
                },
                {
                    title: "产业相关政策",
                    content: industryRelatedPolicy,
                    color: "#fff",
                    bgColor: "rgba(28, 54, 127, 1)",
                },
            ];
        }

        return policy;
    };

    const updatePageView = async p => {
        let data;
        try {
            let res = await updateAreaInfoManagementPageView(p);
            if (res.data.status == 0) {
                data = res.data.data;
            } else {
                toast(res.data.msg, "error");
            }
        } catch (error) {
            console.log(error);
        }
        return data;
    };
    return {
        getData,
        getAreaIndustrialAllocation,
        setDetailPolicy,
        setPolicy,
        updatePageView,
        getRegistrationPackage,
    };
}